package com.webonlineapp.hyjavaapexdemo;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import com.hyjavaapex.LibraryInfo;
import com.hyjavaapex.chart.Apexchart;
import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.Html;
import com.vaadin.flow.component.applayout.AppLayout;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.button.ButtonVariant;
import com.vaadin.flow.component.checkbox.Checkbox;
import com.vaadin.flow.component.dependency.CssImport;
import com.vaadin.flow.component.grid.Grid;
import com.vaadin.flow.component.html.H4;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.html.Span;
import com.vaadin.flow.component.icon.Icon;
import com.vaadin.flow.component.icon.VaadinIcon;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.tabs.Tab;
import com.vaadin.flow.component.textfield.TextArea;
import com.vaadin.flow.data.provider.ListDataProvider;
import com.vaadin.flow.data.renderer.ComponentRenderer;
import com.webonlineapp.hyjavaapexdemo.charts.DemoChart;
import com.webonlineapp.hyjavaapexdemo.charts.DemoChartBase;
import com.webonlineapp.hyjavaapexdemo.charts.DemoCharts;
import com.webonlineapp.hyjavaapexdemo.components.ApexchartComponent;
import com.webonlineapp.hyjavaapexdemo.components.ApexchartsImageComponent;
import com.webonlineapp.hyjavaapexdemo.components.JavaScriptComponent;
import com.webonlineapp.hyjavaapexdemo.components.JavaSourceComponent;
import com.webonlineapp.hyjavaapexdemo.components.TabSheet;
import com.webonlineapp.hyjavaapexdemo.util.DesignerIcons;
import com.webonlineapp.hyjavaapexdemo.util.JavascriptUtil;

@CssImport(value = "./styles/app-layout-theme.css", themeFor = "vaadin-app-layout")
@CssImport(value = "./styles/drawer-toggle-theme.css", themeFor = "vaadin-drawer-toggle")
public class DemoPage {
	
	private TabSheet tabSheet = new TabSheet();
	VerticalLayout page1;
	private JavaSourceComponent page2 = new JavaSourceComponent();
	private JavaScriptComponent page3 = new JavaScriptComponent();
	private Checkbox hideMenu = new Checkbox("Hide Menu");
	
	private String compHeight = "65vh";
	
	
	/**
	 * 
	 * @param view
	 * @return
	 */
	public Component buildHeading(AppLayout view, boolean exportServer) {
		VerticalLayout heading = new VerticalLayout();
		heading.setPadding(false);
        
        H4 title = new H4(LibraryInfo.getLibraryName() + 
        					" v" + LibraryInfo.getHyJavaApexAPIVersion() + " Library Demonstration");
        title.getStyle().set("color", "white");
         
        heading.add(title);
        
        return heading;
	}
	
	/**
	 * 
	 * @param view
	 * @return
	 */
	public Component buildMenu(AppLayout view, boolean exportServer) {
		Grid<DemoChart> demoCharts = new Grid<DemoChart>();
        demoCharts.setHeight("100%");
        
        demoCharts.addColumn(new ComponentRenderer<>(demoChart -> {
            if (demoChart.isHeading()) {
                return new Html("<b><i>" + demoChart.getName() + "</i></b>");
            } 
            else {
                return new Html("<span>" + "&nbsp;&nbsp;&nbsp;" + demoChart.getName() + "</span>");
            }
        }));
        
        demoCharts.setItems(DemoCharts.getDemoChartsList());
        
        // Filter out any charts that are not compatible for HyJavaImages eg. real time
        if (exportServer) {
	        ListDataProvider<DemoChart> dataProvider = (ListDataProvider<DemoChart>) demoCharts.getDataProvider();
	        dataProvider.setFilter((dc) -> {
	    		return dc.isShowForExport();
	    	});
        }
        
        demoCharts.addSelectionListener(event -> {
        	Optional<DemoChart> first = event.getFirstSelectedItem();
        	
        	if (first.isPresent()) {
         		DemoChart selectedDemoChart = first.get();
         		if (selectedDemoChart.getChart() != null) {
         			tabSheet.setSelectedIndex(0);

         			if (view.isOverlay()) {
         				view.setDrawerOpened(false);
         			}
         			
         			displayChart(selectedDemoChart.getChart(), exportServer);
          		}
        	}
        });
        
        demoCharts.select(DemoCharts.getDemoChartsList().get(1));
        
        VerticalLayout options = new VerticalLayout();
        options.add(hideMenu);

        hideMenu.addClickListener(clickEvent -> {
        	view.getElement().setAttribute("hide-menu", hideMenu.getValue());
        	JavascriptUtil.triggerResize();
    	});
        
        VerticalLayout menu = new VerticalLayout();
        menu.setId("the-menu");
        menu.setWidthFull();
        menu.setHeight("100%");
        menu.setSpacing(false);
        menu.setPadding(false);
        
        menu.add(demoCharts, options);
        
        return menu;
	}
	
	/**
	 * 
	 * @param selectedDemoChart
	 */
	private void displayChart(DemoChartBase selectedDemoChart, boolean exportServer) {
		List<Apexchart> chartList = new ArrayList<Apexchart>();
		
		Apexchart apexchart = selectedDemoChart.configure();
		if (apexchart != null) {
			chartList.add(apexchart);
		}
		else {
			chartList = selectedDemoChart.getCharts();
		}

		String chartOptionsJs = "";
		String combinedChartOptionsJs = "";
		
		page1.removeAll();
		
		if (exportServer) {
			String[] chartOptionsJsArray = new String[chartList.size()];
			int i = 0;
			
			for (Apexchart chart : chartList) {
				chartOptionsJs = chart.chartOptionsToJs();
				combinedChartOptionsJs = combinedChartOptionsJs + chartOptionsJs;
				
				chartOptionsJsArray[i] = chartOptionsJs;
				i++;
			}
			
			ApexchartsImageComponent apexchartsImageComponent = new ApexchartsImageComponent();
			apexchartsImageComponent.setWidth("100%");
			page1.add(apexchartsImageComponent);
			
			apexchartsImageComponent.displayChartImage(chartOptionsJsArray);
		}
		else {
			for (Apexchart chart : chartList) {
				chartOptionsJs = chart.chartOptionsToJs();
				combinedChartOptionsJs = combinedChartOptionsJs + chartOptionsJs;
				
				ApexchartComponent apexchartComponent = new ApexchartComponent();
	 			apexchartComponent.setWidth("100%");
	 			page1.add(apexchartComponent);
	 			
				apexchartComponent.displayChart(chartOptionsJs);
			}
		}
		
		page2.setJavaSource(selectedDemoChart.getClass().getName());
        page3.setJavaScript(combinedChartOptionsJs);
 	}
	
	/**
	 * 
	 * @param content
	 */
	public void buildTab(VerticalLayout content, boolean exportServer) {
		tabSheet = new TabSheet();
		tabSheet.setWidth("100%");

		// Add tabs and pages to tabsheet
		tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), new Icon(VaadinIcon.BAR_CHART), 
				new Span("Example Chart"), new Span(""))), buildPage1());
		
		tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), DesignerIcons.COFFEE_HOT.create(),
				new Span("Java Source Code"), new Span(""))), buildPage2());
		
		tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), new Icon(VaadinIcon.CURLY_BRACKETS), 
				new Span("Generated Javascript"), new Span(""))), buildPage3());
		
		if (Properties.SHOW_TEST_TAB) {
			tabSheet.addTab(new Tab(new HorizontalLayout(new Span(""), new Icon(VaadinIcon.CHECK), 
					new Span("Test Chart Options"), new Span(""))), buildPage4());
		}
		
		Label header = new Label("Demonstrating various example charts using the " + LibraryInfo.getLibraryName() + " v" + LibraryInfo.getHyJavaApexAPIVersion() + " Library");
		header.getStyle().set("font-weight", "700");
		content.add(header);
		Label spacer = new Label();
		content.add(spacer);
		
		// Add all tab components to the layout
        tabSheet.addComponentsToLayout(content);
        
        tabSheet.addSelectedChangeListener(event -> {
        	if (tabSheet.getSelectedIndex() == 1) {
        		page2.prettify();
        	}
        });
	}
	
	/**
	 * 
	 * @return
	 */
	private VerticalLayout buildPage1() {
		page1 = new VerticalLayout();
		page1.setWidth("100%");
		page1.setMargin(false);
        
        return page1;
	}
	
	/**
	 * 
	 * @return
	 */
	private JavaSourceComponent buildPage2() {
		page2.setHeight(compHeight);
		page2.setWidth("100%");
		
		return page2;
	}
	
	/**
	 * 
	 * @return
	 */
	private JavaScriptComponent buildPage3() {
		page3.setHeight(compHeight);
		page3.setWidth("100%");
		
		return page3;
	}
	
	/**
	 * 
	 * @return
	 */
	private VerticalLayout buildPage4() {
		VerticalLayout page4 = new VerticalLayout();
		
		TextArea chartOptions = new TextArea();
		chartOptions.setLabel("Chart Options");
		chartOptions.setClearButtonVisible(true);
		chartOptions.setPlaceholder("Paste chart options here...");
		chartOptions.setWidth("100%");
		chartOptions.setHeight("400px");
		
		Button displayButton = new Button("Display Chart");
		displayButton.addThemeVariants(ButtonVariant.LUMO_PRIMARY);
		
		ApexchartComponent highchartTest = new ApexchartComponent();
		highchartTest.setHeight(compHeight);
		highchartTest.setWidth("100%");
		
		page4.add(chartOptions);
		page4.add(displayButton);
		page4.add(highchartTest);

		displayButton.addClickListener(clickEvent -> {
			highchartTest.displayChart(chartOptions.getValue());
    	});

		return page4;
	}

}
