package com.webonlineapp.hyjavaapexdemo.components;

import java.util.Base64;
import java.util.Random;

import com.hyjavacharts.hyjavaimages.ImageException;
import com.hyjavacharts.hyjavaimages.ImageFormat;
import com.hyjavacharts.hyjavaimages.ImageGenerator;
import com.hyjavacharts.hyjavaimages.ImageOptions;
import com.hyjavacharts.hyjavaimages.LibraryInfo;
import com.hyjavacharts.hyjavaimages.LibraryType;
import com.vaadin.flow.component.Html;
import com.vaadin.flow.component.Tag;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.button.ButtonVariant;
import com.vaadin.flow.component.html.Image;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.radiobutton.RadioButtonGroup;
import com.vaadin.flow.component.radiobutton.RadioGroupVariant;
import com.vaadin.flow.server.StreamResource;

/**
 * Image generation is dependent on the HyJavaImages library.
 */

@Tag("div")
public class ApexchartsImageComponent extends VerticalLayout {
	private static final long serialVersionUID = 5343841071531323147L;
	
	
	/**
	 * 
	 * @param chartOptionsJs
	 */
	public void displayChartImage(String... chartOptionsJs) {
		removeAll();
		
		String text = "<h4>HyJavaImages v" + LibraryInfo.getHyJavaImagesAPIVersion() + " Demonstration</h4>" + 
				"Generate chart images on the server using the <b>HyJavaApex</b> and <b>HyJavaImages</b> libraries." + 
				"<br>The chart options Javascript is generated using the HyJavaApex library." + 
				"<br>The <b>HyJavaImages</b> library then creates the chart image from the chart options." + 
				"<br>No Javascript is executed on the client browser.";
		
		add(new Html("<div>" + text + "</div>"));
		
		RadioButtonGroup<String> imageFormatGroup = new RadioButtonGroup<>();
		imageFormatGroup.setLabel("Format");
		imageFormatGroup.setItems("png", "jpeg", "webp");
		imageFormatGroup.addThemeVariants(RadioGroupVariant.LUMO_VERTICAL);
		imageFormatGroup.setValue("png");
		add(imageFormatGroup);
		
		RadioButtonGroup<String> resolutionGroup = new RadioButtonGroup<>();
		resolutionGroup.setLabel("Resolution");
		resolutionGroup.setItems("800 x 600", "1600 x 1200", "3200 x 2400");
		resolutionGroup.addThemeVariants(RadioGroupVariant.LUMO_VERTICAL);
		resolutionGroup.setValue("800 x 600");
		add(resolutionGroup);
		
		Button exportButton = new Button("Generate Chart Image");
		exportButton.addThemeVariants(ButtonVariant.LUMO_PRIMARY);
		add(exportButton);

		exportButton.addClickListener(clickEvent -> {
			Random rand = new Random();
			removeAll();
			
			int scale = 1;
			String resolution = resolutionGroup.getValue();
			if (resolution.equals("1600 x 1200")) {
				scale = 2;
			}
			else if (resolution.equals("3200 x 2400")) {
				scale = 4;
			}
			
			ImageFormat imageFormat;
			String format = imageFormatGroup.getValue();
			if (format.equals("png")) {
				imageFormat = ImageFormat.PNG;
			}
			else if (format.equals("jpeg")) {
				imageFormat = ImageFormat.JPEG;
			}
			else {
				imageFormat = ImageFormat.WEBP;
			}

			Image theChart = new Image();
    		ImageGenerator img = new ImageGenerator();
    		img.setJavaScript(LibraryType.APEXCHARTS, "3.33.2");
    		img.setJavaScriptAdditional("https://cdn.jsdelivr.net/npm/moment@2.28.0");
    		
    		// the first element is always the main chart and the first to be displayed.
    		// if more than 1 set of charts, create an array of 2nd element and onwards.
    		// then use these in the setAdditionalChartOptions() method
    		if (chartOptionsJs.length > 1) {
	    		String[] chartOptionsJsArray = new String[chartOptionsJs.length - 1];
	    		for (int i = 1; i < chartOptionsJs.length; i++) {
	    			chartOptionsJsArray[i-1] = chartOptionsJs[i];
	    		}
	    		
	    		img.setAdditionalChartOptions(chartOptionsJsArray);
    		}
    		
    		//img.setDebugHtmlDirectory("/var/chart-debug/");
    		
    		try {
				String base64 = img.toBase64Image(chartOptionsJs[0], 
						new ImageOptions().setFormat(imageFormat).setScale(scale));
				byte [] imageBytes = Base64.getDecoder().decode(base64); 
				
				StreamResource resource = new StreamResource("image" + rand.nextInt(999999999) + 
						(imageFormat == ImageFormat.PNG ? ".png" : imageFormat == ImageFormat.JPEG ? ".jpeg" : ".webp"), 
	    				new ChartImageStream(imageBytes));
	    		theChart = new Image(resource, "");
			} catch (ImageException e) {
				e.printStackTrace();
			}
     		
    		theChart.setWidth("800px");
    		theChart.setHeight("600px");
    		add(theChart);
     	});
	}
	
}
