package com.webonlineapp.hyjavaapexdemo.examplecharts;

import java.util.ArrayList;
import java.util.Calendar;

import com.hyjavaapex.chart.Apexchart;
import com.hyjavaapex.model.apexcharts.ChartOptions;
import com.hyjavaapex.model.apexcharts.Series;
import com.hyjavaapex.model.apexcharts.constants.AxisType;
import com.hyjavaapex.model.apexcharts.constants.ChartType;
import com.hyjavaapex.model.apexcharts.constants.Curve;
import com.hyjavaapex.model.apexcharts.constants.Easing;
import com.hyjavaapex.model.apexcharts.constants.HorizontalAlign;
import com.hyjavaapex.model.apexcharts.series.Data;
import com.hyjavaapex.model.common.Function;
import com.webonlineapp.hyjavaapexdemo.charts.DemoChartBase;

public class RealTime extends DemoChartBase {
	private static final long serialVersionUID = 8451224834547659420L;

	public Apexchart configure() {
		Apexchart apexchart = new Apexchart();
		ChartOptions chartOptions = apexchart.getChartOptions();
		
		chartOptions.getChart().setHeight(450).setType(ChartType.LINE).setId("realtime");
		chartOptions.getChart().getAnimations().setEnabled(true).setEasing(Easing.LINEAR)
			.getDynamicAnimation().setSpeed(1000);
		chartOptions.getChart().getToolbar().setShow(false);
		chartOptions.getChart().getZoom().setEnabled(false);
		
		chartOptions.getDataLabels().setEnabled(false);
		chartOptions.getStroke().setCurve(Curve.SMOOTH);

		chartOptions.getTitle().setText("Dynamic Updating Chart").setAlign((HorizontalAlign.LEFT));
		chartOptions.getSubtitle().setText("(for 30 seconds)").setAlign((HorizontalAlign.LEFT));
		chartOptions.getMarkers().setSize(0);
		
		chartOptions.getXaxis().setType(AxisType.DATETIME);
		chartOptions.getYaxisSingle().setMax(100);
		chartOptions.getLegend().setShow(false);
		
		Series series = new Series();
		series.setDataAsArrayObject(getSeriesData());
		chartOptions.getSeries().add(series);
		
		chartOptions.getChart().getEvents().setMounted(new Function(getLoadFunction()));
		
		return apexchart;
	}
	
	/**
	 * 
	 * @return
	 */
	private ArrayList<Data> getSeriesData() {
		Calendar cal = Calendar.getInstance();

		ArrayList<Data> data = new ArrayList<Data>();
		long time = cal.getTime().getTime();
		int i;
		
		for (i = -19; i <= 0; i += 1) {
			data.add(new Data().setX(time + i * 86400000).setY(Math.floor(Math.random() * (90 - 10 + 1)) + 10));
		}
		
		return data;
	}
	
	/**
	 * 
	 * @return
	 */
	private String getLoadFunction() {
		return 	"var counter = 0;" + 
				"var intervalId = setInterval(function () {" + 
				"var x = (new Date().getTime() + (counter + 1) * 86400000);" + 
				"var y = Math.floor(Math.random() * (90 - 10 + 1)) + 10;" + 
				"chart.appendData([{ data: [{ x: x, y: y } ]}]);" + 
				"counter++;" + 
				"if(counter > 30) {" + 
				"clearInterval(intervalId);" + 
				"}" + 
				"}, 1000);";
	}
	
}