package com.webonlineapp.hyjavachartsdemo9.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.List;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.Stop;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.series.SeriesLine;
import com.hyjavacharts.model.highcharts.yaxis.PlotBands;
import com.webonlineapp.hyjavachartsdemo9.charts.DemoChartBase;

public class CPUUtilization extends DemoChartBase {
	private static final long serialVersionUID = 8451224834547659420L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.getTitle().setText("CPU utilization during last 24 hour time period");
		chartOptions.getChart().setMarginTop(80);
		chartOptions.getLegend().setEnabled(false);

		XAxis xAxi = new XAxis();
		xAxi.setType(AxisType.DATETIME).getTitle().setText("Time");
		xAxi.getDateTimeLabelFormats().setDay("%e. %b");
		chartOptions.getXAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.getTitle().setText("Utilization");
		yAxi.setMax(100);
		yAxi.getLabels().setFormat("{value}%");
		yAxi.getPlotBands().add(new PlotBands().setFrom(0).setTo(25).setColor(new Color().setRGBA(0, 0, 255, 0.07)));
		yAxi.getPlotBands().add(new PlotBands().setFrom(25).setTo(75).setColor(new Color().setRGBA(0, 255, 0, 0.07)));
		yAxi.getPlotBands().add(new PlotBands().setFrom(75).setTo(100).setColor(new Color().setRGBA(250, 0, 0, 0.07)));
		chartOptions.getYAxis().add(yAxi);
		
		chartOptions.getTooltip()
			.setXDateFormat("%A, %b %e, %H:%M:%S")
			.setPointFormat("<b>CPU Utilization {point.y}%</b>")
			.setShared(true);

		SeriesLine seriesLine = new SeriesLine();
		seriesLine.setName("CPU utilization");
		seriesLine.setPointStart(getTimeStart());
		seriesLine.setPointInterval(15 * 60 * 1000); // 15 minutes
		
		seriesLine.getColor()
			.setLinearGradient(Arrays.asList(0, 0, 0, 350))
			.setStops(Arrays.asList(
				new Stop(0, new Color("red")), 
				new Stop(0.7, new Color("green")),
				new Stop(1, new Color("blue"))));

		seriesLine.setDataAsArrayNumber(getData());
		chartOptions.getSeries().add(seriesLine);
		
		setHeight("550px");

		return highChart;
	}

	/**
	 * 
	 * @return
	 */
	private List<Number> getData() {
		List<Number> utilization = new ArrayList<Number>();

		for (int i = 0; i < 96; i++) {
			utilization.add(Math.ceil(Math.random() * 100));
		}

		return utilization;
	}
	
	/**
	 * 
	 * @return
	 */
	private long getTimeStart() {
		Calendar cal = Calendar.getInstance();
		cal.add(Calendar.DAY_OF_MONTH, -1);
		cal.add(Calendar.HOUR, -2);
		
		return cal.getTimeInMillis();
	}

}
