package com.webonlineapp.hyjavachartsdemo9.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.common.GenericOption;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Integration;
import com.hyjavacharts.model.highcharts.series.SeriesNetworkgraph;
import com.hyjavacharts.model.highcharts.series.seriesnetworkgraph.Data;
import com.hyjavacharts.model.highcharts.series.seriesnetworkgraph.Nodes;
import com.hyjavacharts.model.highcharts.series.seriesnetworkgraph.nodes.Marker;
import com.webonlineapp.hyjavachartsdemo9.charts.DemoChartBase;

public class NetworkGraphFlightsES extends DemoChartBase {
	private static final long serialVersionUID = 6895751012791380221L;

	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart()
			.setType(ChartType.NETWORKGRAPH)
			.setMarginTop(80);
		chartOptions.getTitle().setText("South Korea domestic flight routes");

		chartOptions.getPlotOptions().getNetworkgraph()
			.setKeys(Arrays.asList("from", "to"))
			.getLayoutAlgorithm()
				.setIntegration(Integration.VERLET)
				.setLinkLength(100);
		
		chartOptions.getTooltip().getFormatter().setFunctionBody(getTooltipFormatter());

		SeriesNetworkgraph seriesNetworkgraph = new SeriesNetworkgraph();
		seriesNetworkgraph.getDataLabels()
			.setEnabled(true)
			.setLinkFormat("")
			.setAllowOverlap(true)
			.getStyle().setTextOutline("false");
		seriesNetworkgraph.setDataAsArrayObject(getSeriesFlightData());
		seriesNetworkgraph.setNodes(getSeriesNodes());
		chartOptions.getSeries().add(seriesNetworkgraph);

		return highChart;
	}
	
	/**
	 * 
	 * @return
	 */
	private String getTooltipFormatter() {
		return "var info='';" + 
				   "if (this.color == '#E8544E') info='is an aiport with <b>more than 50</b> direct destinations';" + 
				   "if (this.color == '#FFD265') info='is an aiport with <b>more than 10</b> direct destinations';" + 
				   "if (this.color == '#2AA775') info='is an aiport with <b>less than 10</b> direct destinations';" + 
				   "return '<b>'+this.key + '</b>: ' + info;";
	}
	
	/**
	 * 
	 * @return
	 */
	private ArrayList<Data> getSeriesFlightData() {
   		return new ArrayList<Data>(Arrays.asList(
			new Data().setFrom("Seoul ICN").setTo("Daegu"),
			new Data().setFrom("Seoul ICN").setTo("Busan"),
			new Data().setFrom("Busan").setTo("Seoul GMP"),
			new Data().setFrom("Busan").setTo("Yangyang"),

			new Data().setFrom("Daegu").setTo("Seoul GMP"),
			new Data().setFrom("Daegu").setTo("Jeju"),
			      
			new Data().setFrom("Seoul GMP").setTo("Gwangju"),
			new Data().setFrom("Seoul GMP").setTo("Yeosu"),
			new Data().setFrom("Seoul GMP").setTo("Sacheon"),
			new Data().setFrom("Seoul GMP").setTo("Ulsan"),
			new Data().setFrom("Seoul GMP").setTo("Pohang"),
			      
			new Data().setFrom("Jeju").setTo("Gwangju"),
			new Data().setFrom("Jeju").setTo("Gunsan"),
			new Data().setFrom("Jeju").setTo("Wonju"),
			new Data().setFrom("Jeju").setTo("Yangyang"),
			new Data().setFrom("Jeju").setTo("Daegu"),
			new Data().setFrom("Jeju").setTo("Yeosu"),
			new Data().setFrom("Jeju").setTo("Sacheon"),
			new Data().setFrom("Jeju").setTo("Ulsan"),
			new Data().setFrom("Jeju").setTo("Busan"),
			new Data().setFrom("Jeju").setTo("Cheongju")
			));
    }
	
	/**
	 * 
	 * @return
	 */
	private ArrayList<Nodes> getSeriesNodes() {
   		return new ArrayList<Nodes>(Arrays.asList(
			new Nodes().setId("Seoul ICN").setColor(new Color("#E8544E")).setMarker(new Marker().setRadius(30)),
   			new Nodes().setId("Daegu").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   			new Nodes().setId("Busan").setColor(new Color("#E8544E")).setMarker(new Marker().setRadius(30)),
   			new Nodes().setId("Seoul GMP").setColor(new Color("#FFD265")).setMarker(new Marker().setRadius(20)),
   	        new Nodes().setId("Jeju").setColor(new Color("#E8544E")).setMarker(new Marker().setRadius(30)),
   	        new Nodes().setId("Gwangju").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   	        new Nodes().setId("Yeosu").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   	        new Nodes().setId("Sacheon").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   	        new Nodes().setId("Ulsan").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   	        new Nodes().setId("Pohang").setColor(new Color("#FFD265")).setMarker(new Marker().setRadius(20)),
   	        new Nodes().setId("Gunsan").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   	        new Nodes().setId("Wonju").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   	        new Nodes().setId("Yangyang").setColor(new Color("#2AA775")).setMarker(new Marker().setRadius(10)),
   	        new Nodes().setId("Cheongju").setColor(new Color("#FFD265")).setMarker(new Marker().setRadius(20))
   	        ));
	}

}
