package com.webonlineapp.hyjavastockdemo9.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavastock.chart.Highstock;
import com.hyjavastock.model.common.Unit;
import com.hyjavastock.model.highstock.ChartOptions;
import com.hyjavastock.model.highstock.YAxis;
import com.hyjavastock.model.highstock.constants.HorizontalAlign;
import com.hyjavastock.model.highstock.constants.SeriesType;
import com.hyjavastock.model.highstock.series.SeriesCandlestick;
import com.hyjavastock.model.highstock.series.SeriesColumn;
import com.hyjavastock.model.highstock.series.SeriesSma;
import com.hyjavastock.model.highstock.series.SeriesVbp;
import com.webonlineapp.hyjavastockdemo9.chartdata.AAPLOpenHighLowCloseData;
import com.webonlineapp.hyjavastockdemo9.chartdata.AAPLVolumeData;
import com.webonlineapp.hyjavastockdemo9.charts.DemoChartBase;

public class SMAVolumeByPrice extends DemoChartBase {
	private static final long serialVersionUID = 8451224834547659420L;

	public Highstock configure() {
		Highstock highStock = new Highstock();
		ChartOptions chartOptions = highStock.getChartOptions();
		
		chartOptions.getStockTools().getGui().setEnabled(false);
		
		chartOptions.getTitle().setText("AAPL Historical");
		chartOptions.getSubtitle().setText("With SMA and Volume by Price technical indicators");
		chartOptions.getRangeSelector().setSelected(2);
		
		YAxis yAxi = new YAxis();
		yAxi.setStartOnTick(false).setEndOnTick(false).setHeight("60%").setLineWidth(2);
		yAxi.getLabels().setAlign(HorizontalAlign.RIGHT).setX(-3);
		yAxi.getTitle().setText("OHLC");
		yAxi.getResize().setEnabled(true);
		chartOptions.getYAxis().add(yAxi);
		
		yAxi = new YAxis();
		yAxi.getLabels().setAlign(HorizontalAlign.RIGHT).setX(-3);
		yAxi.getTitle().setText("Volume");
		yAxi.setTop("65%").setHeight("35%").setOffset(0).setLineWidth(2);
		chartOptions.getYAxis().add(yAxi);
		
		chartOptions.getTooltip().setSplit(true);
		
		chartOptions.getPlotOptions().getSeries().getDataGrouping().getUnits().add(new Unit("week", new ArrayList<Number>(Arrays.asList(1))));
		chartOptions.getPlotOptions().getSeries().getDataGrouping().getUnits().add(new Unit("month", new ArrayList<Number>(Arrays.asList(1,2,3,4,6))));
				
		SeriesCandlestick seriesCandlestick = new SeriesCandlestick();
		seriesCandlestick.setType(SeriesType.CANDLESTICK).setName("AAPL").setId("aapl").setZIndex(2);
		seriesCandlestick.getDataAsJsValue().setJsValue(new AAPLOpenHighLowCloseData().get());
		chartOptions.getSeries().add(seriesCandlestick);

		SeriesColumn seriesColumn = new SeriesColumn();
		seriesColumn.setType(SeriesType.COLUMN).setName("Volume").setId("volume").setYAxis(1);
		seriesColumn.getDataAsJsValue().setJsValue(new AAPLVolumeData().get());
		chartOptions.getSeries().add(seriesColumn);
		
		SeriesVbp seriesVpb = new SeriesVbp();
		seriesVpb.setType(SeriesType.VBP).setLinkedTo("aapl");
		seriesVpb.getParams().setVolumeSeriesID("volume");
		seriesVpb.getDataLabels().setEnabled(false);
		seriesVpb.getZoneLines().setEnabled(false);
		chartOptions.getSeries().add(seriesVpb);
		
		SeriesSma seriesSma = new SeriesSma();
		seriesSma.setType(SeriesType.SMA).setLinkedTo("aapl").setZIndex(1).getMarker().setEnabled(false);
		
		return highStock;
	}
	
}