package com.webonlineapp;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.hyjavaapex.chart.Apexchart;
import com.hyjavacharts.chart.Highchart;
import com.hyjavastock.chart.Highstock;

/*
 * A very primitive and simple proof of concept example to show how to integrate 
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library 
 *   
 * in a web application.
 * 
 * The Charts available are: 
 *   Highcharts line and pie charts
 *   Highcharts Stock column chart
 *   ApexCharts basic column chart
 *   
 * ?chart=line
 * ?chart=pie
 * ?chart=stock
 * ?chart=apex
 * 
 */
public class HyJavaChartsSimpleDemo extends HttpServlet {
	private static final long serialVersionUID = 1L;
       
    /**
     * 
     */
    public HyJavaChartsSimpleDemo() {
        super();
    }

	/**
	 * 
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		String reqChart = request.getParameter("chart") == null ? "line" : request.getParameter("chart");
		
		response.setContentType("text/html");
        PrintWriter printWriter  = response.getWriter();
        
        // Add javascript
        printWriter.println("<script src=\"https://code.highcharts.com/stock/9.3.3/highstock.js\"></script>");
        printWriter.println("<script src=\"https://code.highcharts.com/9.3.3/modules/exporting.js\"></script>");
        printWriter.println("<script src=\"https://code.highcharts.com/stock/9.3.3/modules/data.js\"></script>");
        printWriter.println("<script src=\"https://cdn.jsdelivr.net/npm/apexcharts@3.33.2\"></script>");

        
        printWriter.println("<div id=\"container\" style=\"min-width: 310px; max-width: 800px; height: 400px; margin: 0 auto\"></div>");
        
        printWriter.println("<script>");
        
        if (reqChart.equals("stock")) {
        	Highstock hs = new HighstockColumn().configure();
        	
        	// handle any global chart options
	        String global = hs.globalOptionsToJs();
	        if (global != null) {
	        	printWriter.println("Highcharts.setOptions(" + global + ");");
	        }
	        
	        // chart options
	        printWriter.println("Highcharts.stockChart('container', " + hs.chartOptionsToJs() + ");");
        }
        else if (reqChart.equals("apex")) {
        	Apexchart apexchart = new ApexChartsBasicColumn().configure();
        	
        	printWriter.println("var chart = new ApexCharts(document.querySelector('#container'), " + apexchart.chartOptionsToJs() + ");");
        	printWriter.println("chart.render();");
        }
        else {
        	Highchart hc = null;
        	
        	if (reqChart.equals("line")) {
        		hc = new HighchartsLine().configure();
        	}
        	else {
        		hc = new HighchartsPie().configure();
        	}
        	
        	// handle any global chart options
	        String global = hc.globalOptionsToJs();
	        if (global != null) {
	        	printWriter.println("Highcharts.setOptions(" + global + ");");
	        }
	        
	        // chart options
	        printWriter.println("Highcharts.chart('container', " + hc.chartOptionsToJs() + ");");
        }
        
        printWriter.println("</script>");
	}

	/**
	 * 
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		doGet(request, response);
	}

}
