package com.webonlineapp;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.annotation.WebServlet;

import com.hyjavaapex.chart.Apexchart;
import com.hyjavacharts.chart.Highchart;
import com.hyjavastock.chart.Highstock;
import com.vaadin.annotations.Theme;
import com.vaadin.annotations.VaadinServletConfiguration;
import com.vaadin.server.VaadinRequest;
import com.vaadin.server.VaadinServlet;
import com.vaadin.ui.Button;
import com.vaadin.ui.ComboBox;
import com.vaadin.ui.Component;
import com.vaadin.ui.UI;
import com.vaadin.ui.VerticalLayout;
import com.webonlineapp.charts.ApexChartsBasicColumn;
import com.webonlineapp.charts.HighchartsLine;
import com.webonlineapp.charts.HighchartsPie;
import com.webonlineapp.charts.HighstockColumn;

/*
 * A simple proof of concept example application to show how to integrate
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library 
 *   
 * in a Vaadin application.
 * 
 */
@Theme("demotheme")
public class DemoUI extends UI {
	private static final long serialVersionUID = -4384922097192602164L;

	@Override
    protected void init(VaadinRequest vaadinRequest) {
    	final VerticalLayout layout = new VerticalLayout();
         
        layout.addComponent(buildPage());
        
        setContent(layout);
    }
    
    /**
     * 
     * @return
     */
    private Component buildPage() {
    	VerticalLayout layout = new VerticalLayout();
    	
    	List<String> charts = new ArrayList<>();
    	charts.add("Highcharts Line");
    	charts.add("Highcharts Pie");
    	charts.add("Highstock Column");
    	charts.add("ApexCharts Column");

    	ComboBox<String> select =  new ComboBox<>("Select Chart");
    	select.setItems(charts);
    	select.setTextInputAllowed(false);
    	select.setEmptySelectionAllowed(false);
    	select.setValue("Highcharts Line");
    	select.setWidth("200px");
    	layout.addComponent(select);
    	
        Button button = new Button("Display Chart");
        layout.addComponent(button);
        
        VerticalLayout chartComponent = new VerticalLayout();
        layout.addComponent(chartComponent);
         
        button.addClickListener(e -> {
            chartComponent.removeAllComponents();
            chartComponent.addComponent(buildChart(select.getValue()));
        });
 
        return layout;
    }
    
    /**
     * 
     * @return
     */
    private Component buildChart(String chartName) {
    	ChartComponent hcComponent = new ChartComponent();
    	
    	if (chartName.equals("Highstock Column")) {
    		Highstock hs = new HighstockColumn().configure();
    		
    		String globalOptionsJs = hs.globalOptionsToJs();
			String chartOptionsJs = hs.chartOptionsToJs();
			
			if (globalOptionsJs != null) 
				hcComponent.setOptions(globalOptionsJs);
			hcComponent.setChartoptions(chartOptionsJs);
			hcComponent.setChartType("highstock");
    	}
    	else  if (chartName.equals("ApexCharts Column")) {
    		Apexchart apexchart = new ApexChartsBasicColumn().configure();
    		
			String chartOptionsJs = apexchart.chartOptionsToJs();
			
			hcComponent.setChartoptions(chartOptionsJs);
			hcComponent.setChartType("apexchart");
    	}
    	else {
	    	Highchart hc = null;
	    	if (chartName.equals("Highcharts Line")) {
	    		hc = new HighchartsLine().configure();
	    	}
	    	else {
	    		hc = new HighchartsPie().configure();
	    	}
			
			String globalOptionsJs = hc.globalOptionsToJs();
			String chartOptionsJs = hc.chartOptionsToJs();
			
			if (globalOptionsJs != null) 
				hcComponent.setOptions(globalOptionsJs);
			hcComponent.setChartoptions(chartOptionsJs);
			hcComponent.setChartType("highcharts");
    	}
    	
    	hcComponent.setWidth("800px");
    	
		return hcComponent;
    }
    

    @WebServlet(urlPatterns = "/*", name = "DemoUIServlet", asyncSupported = true)
    @VaadinServletConfiguration(ui = DemoUI.class, productionMode = false)
    public static class DemoUIServlet extends VaadinServlet {
		private static final long serialVersionUID = -7065516492723139427L;
    }
}
