package com.webonlineapp;

import java.util.ArrayList;
import java.util.List;

import com.hyjavaapex.chart.Apexchart;
import com.hyjavacharts.chart.Highchart;
import com.hyjavastock.chart.Highstock;
import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.button.ButtonVariant;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.select.Select;
import com.vaadin.flow.router.Route;
import com.webonlineapp.charts.ApexChartsBasicColumn;
import com.webonlineapp.charts.HighchartsLine;
import com.webonlineapp.charts.HighchartsPie;
import com.webonlineapp.charts.HighstockColumn;

/*
 * A simple proof of concept example application to show how to integrate
 *   Highcharts and the HyJavaCharts library
 * plus
 *   Highcharts Stock and the HyJavaStock library
 * plus
 *   ApexCharts and the HyJavaApex library 
 *   
 * in a Vaadin 14+ application.
 * 
 */
@Route("")
public class MainView extends VerticalLayout {
	private static final long serialVersionUID = 5516451139589179962L;
	

	/**
	 * 
	 */
	public MainView() {
        add(buildPage());
    }
	
	/**
     * 
     * @return
     */
    private Component buildPage() {
    	VerticalLayout layout = new VerticalLayout();
    	
    	List<String> charts = new ArrayList<>();
    	charts.add("Highcharts Line");
    	charts.add("Highcharts Pie");
    	charts.add("Highstock Column");
    	charts.add("ApexCharts Column");

    	Select<String> select =  new Select<>("Select Chart");
    	select.setItems(charts);
     	select.setValue("Highcharts Line");
     	select.setWidth("200px");
    	add(select);
    	
        Button button = new Button("Display Chart");
        button.addThemeVariants(ButtonVariant.LUMO_PRIMARY);
        add(button);
        
        VerticalLayout chartComponent = new VerticalLayout();
        add(chartComponent);
         
        button.addClickListener(e -> {
            chartComponent.removeAll();;
            chartComponent.add(buildChart(select.getValue()));
        });
 
        return layout;
    }
    
    /**
     * 
     * @param chartName
     * @return
     */
    private Component buildChart(String chartName) {
    	ChartComponent chartComponent = new ChartComponent();
    	chartComponent.setWidth("800px");
    	
    	if (chartName.equals("Highstock Column")) {
    		Highstock hs = new HighstockColumn().configure();
    		chartComponent.setChartType("highstock");
    		
    		String globalOptionsJs = hs.globalOptionsToJs();
			String chartOptionsJs = hs.chartOptionsToJs();
			
			if (globalOptionsJs != null) {
				chartComponent.displayChart(globalOptionsJs, chartOptionsJs);
			}
			else {
				chartComponent.displayChart(chartOptionsJs);
			}
    	}
    	else if (chartName.equals("ApexCharts Column")) {
    		Apexchart apexchart = new ApexChartsBasicColumn().configure();
    		chartComponent.setChartType("apexchart");
    		
			String chartOptionsJs = apexchart.chartOptionsToJs();
			chartComponent.displayChart(chartOptionsJs);
    	}
    	else {
    		chartComponent.setChartType("highcharts");
    		
	    	Highchart hc = null;
	    	if (chartName.equals("Highcharts Line")) {
	    		hc = new HighchartsLine().configure();
	    	}
	    	else {
	    		hc = new HighchartsPie().configure();
	    	}
			
			String globalOptionsJs = hc.globalOptionsToJs();
			String chartOptionsJs = hc.chartOptionsToJs();
			
			if (globalOptionsJs != null) {
				chartComponent.displayChart(globalOptionsJs, chartOptionsJs);
			}
			else {
				chartComponent.displayChart(chartOptionsJs);
			}
    	}
		
		return chartComponent;
    }
}
